@@ -26,6 +26,7 @@
 #include "jprocessor.h"
 #include "jresolver.h"
 #include "jconfig.h"
+#include "jdevice.h"
 
 jconfig_settings	jconfig_Settings;
 
@@ -395,3 +396,20 @@ int jconfig_FindMatchingLocalNetworkIndex(const jbase_mutableaddress *network, i
 	return 64000;
 }
 
+void jconfig_SelectDevice(const char *deviceName) {
+	int i;
+
+	jconfig_Settings.deviceName = deviceName;
+
+	for (i=0; i<jdevice_DevicesCount; i++) {
+		if (!strcmp(jdevice_Devices[i].name, jconfig_Settings.deviceName)) {
+			jconfig_Settings.device = jdevice_Devices + i;
+			break;
+		}
+	}
+
+	if (i >= jdevice_DevicesCount) {
+		jconfig_Settings.device = jdevice_CreateSingleDevice(jconfig_Settings.deviceName);
+	}
+}
+
