@@ -26,7 +26,7 @@
 #include "jbase.h"
 
 typedef struct __jconfig_settings {
-	char		*deviceName;
+	const char	*deviceName;
 	const jbase_device *device;
 	gboolean	onoffContentFiltering;
 	gboolean	onoffPromisc;
@@ -53,6 +53,8 @@ int jconfig_FindBpfFilterByName(char *filterName);
 void jconfig_AddLocalNetwork(const jbase_mutableaddress *network, const jbase_mutableaddress *netmask, int af);
 int jconfig_FindMatchingLocalNetworkIndex(const jbase_mutableaddress *network, int af);
 
+void jconfig_SelectDevice(const char *deviceName);
+
 extern jconfig_settings	jconfig_Settings;
 
 #define JCONFIG_BPFFILTERS_LEN	(jconfig_Settings._bpfFilters->len/2)
