@@ -32,6 +32,7 @@
 #include "jcursesdisplay.h"
 #include "jtxtdisplay.h"
 #include "juiadisplay.h"
+#include "jnetdisplay.h"
 
 #define			DEBUGOUT_NONE	0
 #define			DEBUGOUT_SYSLOG	1
@@ -53,6 +54,7 @@ void debug(int priority, const char *format, ...) {
 	switch (debugOut) {
 		case DEBUGOUT_FILE:
 			fprintf(debugFile, "%d - %d, %s\n", getpid(), priority, buffer);
+			fflush(debugFile);
 			break;
 #ifdef SUPPORT_SYSLOG
 		case DEBUGOUT_SYSLOG:
@@ -130,6 +132,8 @@ void parseCommandLineAndConfig(int argc, char ** argv) {
 				currentDisplay = &jcursesdisplay_Functions;
 			} else if (jtxtdisplay_Functions.supported && !strcmp(argv[a], "text")) {
 				currentDisplay = &jtxtdisplay_Functions;
+			} else if (jnetdisplay_Functions.supported && !strcmp(argv[a], "jnet")) {
+				currentDisplay = &jnetdisplay_Functions;
 			} else if (juiadisplay_Functions.supported && !strcmp(argv[a], "uia")) {
 				currentDisplay = &juiadisplay_Functions;
 			} else {
@@ -265,19 +269,7 @@ void initializeDevices() {
 				exit(255);
 			}
 	} else if (jconfig_Settings.deviceName) {
-		int i;
-		for (i=0; i<jdevice_DevicesCount; i++) {
-			if (!strcmp(jdevice_Devices[i].name, jconfig_Settings.deviceName)) {
-				jconfig_Settings.device = jdevice_Devices + i;
-				break;
-			}
-		}
-
-		if (i >= jdevice_DevicesCount) {
-			if (!(jconfig_Settings.device = jdevice_CreateSingleDevice(jconfig_Settings.deviceName))) {
-				exit(255);
-			}
-		}
+		jconfig_SelectDevice(jconfig_Settings.deviceName);
 	}
 
 	if (!jconfig_Settings.device) {
@@ -311,12 +303,17 @@ int main(int argc, char ** argv) {
 	jconfig_ConfigureModules();
 	initializeDevices();
 
+	jresolver_Initialize();
 	currentDisplay->setup();
 
 	while (TRUE) {
 
 		jprocessor_ResetStats();
 
+		if (!currentDisplay->prerunsetup()) {
+			break;
+		}
+
 		jcapture_SetDevice(jconfig_Settings.device);
 		jcapture_SetBpfFilterText(jconfig_GetSelectedBpfFilterText());
 
@@ -343,5 +340,8 @@ int main(int argc, char ** argv) {
 	}
 
 	currentDisplay->shutdown();
+
+	jresolver_Shutdown();
+
 	return 0;
 }
